"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _react2 = require("@emotion/react");

var _surfaceProvider = require("./surface-provider");

/** @jsx jsx */
var baseStyles = (0, _react2.css)({
  position: 'absolute',
  borderRadius: 'inherit',
  cursor: 'pointer',
  inset: 0,
  // eslint-disable-next-line @repo/internal/styles/no-nested-styles
  '~ *': {
    position: 'relative',
    pointerEvents: 'none'
  }
});

/**
 *
 * @example
 * ```js
 * // a minimal icon button
 * <Box as="button">
 *   <InteractionSurface>
 *    <WarningIcon label="icon button" />
 *  </InteractionSurface>
 * </Box>
 * ```
 */
var InteractionSurface = function InteractionSurface(_ref) {
  var appearance = _ref.appearance,
      children = _ref.children,
      testId = _ref.testId;
  var defaultSurface = (0, _react.useContext)(_surfaceProvider.SurfaceContext);
  var surface = appearance || defaultSurface; // This case will occur if the Box has not set a bg color and the ancestor surface
  // is an elevation. An alternative would be to throw an error here as it may be better
  // to ensure correct predictable behaviour based on user specification.

  if (!(surface in backgroundActiveColorMap)) {
    surface = 'neutral';
  }

  return (0, _react2.jsx)(_react.Fragment, null, (0, _react2.jsx)("span", {
    "data-testid": testId,
    css: [baseStyles, surface && backgroundHoverColorMap[surface], surface && backgroundActiveColorMap[surface]]
  }), children);
};

var _default = InteractionSurface;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::5289ea44928c279ad02274850623c9d1>>
 * @codegenId interactions
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["background"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-light.tsx <<SignedSource::07ef29d58a2b23af8b098515466d7e22>>
 */

exports.default = _default;
var backgroundActiveColorMap = {
  'inverse.subtle': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-inverse-subtle-pressed, #00000052)"
    }
  }),
  input: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-input-pressed, #FFFFFF)"
    }
  }),
  neutral: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-neutral-pressed, #091E424F)"
    }
  }),
  'neutral.subtle': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-neutral-subtle-pressed, #091E4224)"
    }
  }),
  'neutral.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-neutral-bold-pressed, #172B4D)"
    }
  }),
  'brand.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-brand-bold-pressed, #09326C)"
    }
  }),
  selected: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-selected-pressed, #85B8FF)"
    }
  }),
  'selected.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-selected-bold-pressed, #09326C)"
    }
  }),
  danger: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-danger-pressed, #FF9C8F)"
    }
  }),
  'danger.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-danger-bold-pressed, #601E16)"
    }
  }),
  warning: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-warning-pressed, #F5CD47)"
    }
  }),
  'warning.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-warning-bold-pressed, #B38600)"
    }
  }),
  success: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-success-pressed, #7EE2B8)"
    }
  }),
  'success.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-success-bold-pressed, #164B35)"
    }
  }),
  discovery: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-discovery-pressed, #B8ACF6)"
    }
  }),
  'discovery.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-discovery-bold-pressed, #352C63)"
    }
  }),
  information: (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-information-pressed, #85B8FF)"
    }
  }),
  'information.bold': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-background-information-bold-pressed, #09326C)"
    }
  }),
  'elevation.surface': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-surface-pressed, #DCDFE4)"
    }
  }),
  'elevation.surface.raised': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-surface-raised-pressed, #DCDFE4)"
    }
  }),
  'elevation.surface.overlay': (0, _react2.css)({
    ':active': {
      backgroundColor: "var(--ds-surface-overlay-pressed, #DCDFE4)"
    }
  })
};
var backgroundHoverColorMap = {
  'inverse.subtle': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-inverse-subtle-hovered, #0000003D)"
    }
  }),
  input: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-input-hovered, #F7F8F9)"
    }
  }),
  neutral: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-neutral-hovered, #091E4224)"
    }
  }),
  'neutral.subtle': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-neutral-subtle-hovered, #091E420F)"
    }
  }),
  'neutral.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-neutral-bold-hovered, #2C3E5D)"
    }
  }),
  'brand.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-brand-bold-hovered, #0055CC)"
    }
  }),
  selected: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-selected-hovered, #CCE0FF)"
    }
  }),
  'selected.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-selected-bold-hovered, #0055CC)"
    }
  }),
  danger: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-danger-hovered, #FFD2CC)"
    }
  }),
  'danger.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-danger-bold-hovered, #AE2A19)"
    }
  }),
  warning: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-warning-hovered, #F8E6A0)"
    }
  }),
  'warning.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-warning-bold-hovered, #CF9F02)"
    }
  }),
  success: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-success-hovered, #BAF3DB)"
    }
  }),
  'success.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-success-bold-hovered, #216E4E)"
    }
  }),
  discovery: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-discovery-hovered, #DFD8FD)"
    }
  }),
  'discovery.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-discovery-bold-hovered, #5E4DB2)"
    }
  }),
  information: (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-information-hovered, #CCE0FF)"
    }
  }),
  'information.bold': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-background-information-bold-hovered, #0055CC)"
    }
  }),
  'elevation.surface': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-surface-hovered, #F1F2F4)"
    }
  }),
  'elevation.surface.raised': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-surface-raised-hovered, #F1F2F4)"
    }
  }),
  'elevation.surface.overlay': (0, _react2.css)({
    ':hover': {
      backgroundColor: "var(--ds-surface-overlay-hovered, #F1F2F4)"
    }
  })
};
/**
 * @codegenEnd
 */