"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = require("react");

var _react2 = require("@emotion/react");

var _tinyInvariant = _interopRequireDefault(require("tiny-invariant"));

var _colorMap = _interopRequireDefault(require("../internal/color-map"));

var _surfaceProvider = require("./surface-provider");

var _excluded = ["children"];
var asAllowlist = ['span', 'div', 'p', 'strong'];
var fontFamily = "-apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', 'Oxygen', 'Ubuntu', 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif";
var fontSizeMap = {
  '11px': (0, _react2.css)({
    fontSize: '11px'
  }),
  '12px': (0, _react2.css)({
    fontSize: '12px'
  }),
  '14px': (0, _react2.css)({
    fontSize: '14px'
  })
};
// NOTE: can't use numbers as keys or Constellation won't build. Weird one.
var fontWeightMap = {
  '400': (0, _react2.css)({
    fontWeight: 400
  }),
  '500': (0, _react2.css)({
    fontWeight: 500
  }),
  '600': (0, _react2.css)({
    fontWeight: 600
  }),
  '700': (0, _react2.css)({
    fontWeight: 700
  })
};
var lineHeightMap = {
  '12px': (0, _react2.css)({
    lineHeight: '12px'
  }),
  '16px': (0, _react2.css)({
    lineHeight: '16px'
  }),
  '20px': (0, _react2.css)({
    lineHeight: '20px'
  }),
  '24px': (0, _react2.css)({
    lineHeight: '24px'
  }),
  '28px': (0, _react2.css)({
    lineHeight: '28px'
  }),
  '32px': (0, _react2.css)({
    lineHeight: '32px'
  }),
  '40px': (0, _react2.css)({
    lineHeight: '40px'
  })
};
var textAlignMap = {
  center: (0, _react2.css)({
    textAlign: 'center'
  }),
  end: (0, _react2.css)({
    textAlign: 'end'
  }),
  start: (0, _react2.css)({
    textAlign: 'start'
  })
};
var textTransformMap = {
  none: (0, _react2.css)({
    textTransform: 'none'
  }),
  lowercase: (0, _react2.css)({
    textTransform: 'lowercase'
  }),
  uppercase: (0, _react2.css)({
    textTransform: 'uppercase'
  })
};
var verticalAlignMap = {
  top: (0, _react2.css)({
    verticalAlign: 'top'
  }),
  middle: (0, _react2.css)({
    verticalAlign: 'middle'
  }),
  bottom: (0, _react2.css)({
    verticalAlign: 'bottom'
  })
};
var baseStyles = (0, _react2.css)({
  boxSizing: 'border-box',
  margin: '0px',
  padding: '0px',
  fontFamily: fontFamily
});
var truncateStyles = (0, _react2.css)({
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  whiteSpace: 'nowrap'
});
/**
 * Custom hook designed to abstract the parsing of the color props and make it clearer in the future how color is reconciled between themes and tokens.
 */

var useColor = function useColor(colorProp) {
  var surface = (0, _surfaceProvider.useSurface)();
  var inverseTextColor = _colorMap.default[surface];
  /**
   * Where the color of the surface is inverted we override the user choice
   * as there is no valid choice that is not covered by the override.
   */

  var color = inverseTextColor !== null && inverseTextColor !== void 0 ? inverseTextColor : colorProp;
  return color;
};

var HasTextAncestorContext = /*#__PURE__*/(0, _react.createContext)(false);

var useHasTextAncestor = function useHasTextAncestor() {
  return (0, _react.useContext)(HasTextAncestorContext);
};
/**
 * __Text__
 *
 * Text is a primitive component that has the Atlassian Design System's design guidelines baked in.
 * This includes considerations for text attributes such as color, font size, font weight, and line height.
 * It renders a `span` by default.
 *
 * @internal
 */


var Text = function Text(_ref) {
  var children = _ref.children,
      props = (0, _objectWithoutProperties2.default)(_ref, _excluded);
  var _props$as = props.as,
      Component = _props$as === void 0 ? 'span' : _props$as,
      colorProp = props.color,
      fontSize = props.fontSize,
      fontWeight = props.fontWeight,
      lineHeight = props.lineHeight,
      _props$shouldTruncate = props.shouldTruncate,
      shouldTruncate = _props$shouldTruncate === void 0 ? false : _props$shouldTruncate,
      textAlign = props.textAlign,
      textTransform = props.textTransform,
      verticalAlign = props.verticalAlign,
      testId = props.testId,
      UNSAFE_style = props.UNSAFE_style,
      id = props.id;
  (0, _tinyInvariant.default)(asAllowlist.includes(Component), "@atlaskit/ds-explorations: Text received an invalid \"as\" value of \"".concat(Component, "\""));
  var color = useColor(colorProp);
  var isWrapped = useHasTextAncestor();
  /**
   * If the text is already wrapped and applies no props we can just
   * render the children directly as a fragment.
   */

  if (isWrapped && Object.keys(props).length === 0) {
    return (0, _react2.jsx)(_react.Fragment, null, children);
  }

  var component = (0, _react2.jsx)(Component, {
    style: UNSAFE_style,
    css: [baseStyles, color && textColorMap[color], fontSize && fontSizeMap[fontSize], fontWeight && fontWeightMap[fontWeight], lineHeight && lineHeightMap[lineHeight], shouldTruncate && truncateStyles, textAlign && textAlignMap[textAlign], textTransform && textTransformMap[textTransform], verticalAlign && verticalAlignMap[verticalAlign]],
    "data-testid": testId,
    id: id
  }, children);
  return isWrapped ? // no need to re-apply context if the text is already wrapped
  component : (0, _react2.jsx)(HasTextAncestorContext.Provider, {
    value: true
  }, component);
};

var _default = Text;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::920426feace841166c6f4ffdc49ae26d>>
 * @codegenId colors
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["text"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-light.tsx <<SignedSource::07ef29d58a2b23af8b098515466d7e22>>
 */

exports.default = _default;
var textColorMap = {
  'color.text': (0, _react2.css)({
    color: "var(--ds-text, #172B4D)"
  }),
  subtle: (0, _react2.css)({
    color: "var(--ds-text-subtle, #42526E)"
  }),
  subtlest: (0, _react2.css)({
    color: "var(--ds-text-subtlest, #7A869A)"
  }),
  disabled: (0, _react2.css)({
    color: "var(--ds-text-disabled, #A5ADBA)"
  }),
  inverse: (0, _react2.css)({
    color: "var(--ds-text-inverse, #FFFFFF)"
  }),
  brand: (0, _react2.css)({
    color: "var(--ds-text-brand, #0065FF)"
  }),
  selected: (0, _react2.css)({
    color: "var(--ds-text-selected, #0052CC)"
  }),
  danger: (0, _react2.css)({
    color: "var(--ds-text-danger, #DE350B)"
  }),
  warning: (0, _react2.css)({
    color: "var(--ds-text-warning, #974F0C)"
  }),
  'warning.inverse': (0, _react2.css)({
    color: "var(--ds-text-warning-inverse, #172B4D)"
  }),
  success: (0, _react2.css)({
    color: "var(--ds-text-success, #006644)"
  }),
  discovery: (0, _react2.css)({
    color: "var(--ds-text-discovery, #403294)"
  }),
  information: (0, _react2.css)({
    color: "var(--ds-text-information, #0052CC)"
  })
};
/**
 * @codegenEnd
 */