/** @jsx jsx */
import { Children, forwardRef, Fragment, memo } from 'react';
import { css, jsx } from '@emotion/react';
const flexAlignItemsMap = {
  center: css({
    alignItems: 'center'
  }),
  baseline: css({
    alignItems: 'baseline'
  }),
  flexStart: css({
    alignItems: 'flex-start'
  }),
  flexEnd: css({
    alignItems: 'flex-end'
  }),
  start: css({
    alignItems: 'start'
  }),
  end: css({
    alignItems: 'end'
  })
};
const flexJustifyContentMap = {
  center: css({
    justifyContent: 'center'
  }),
  flexStart: css({
    justifyContent: 'flex-start'
  }),
  'space-between': css({
    justifyContent: 'space-between'
  }),
  flexEnd: css({
    justifyContent: 'flex-end'
  }),
  start: css({
    justifyContent: 'start'
  }),
  end: css({
    justifyContent: 'end'
  }),
  spaceBetween: css({
    justifyContent: 'space-between'
  })
};
const flexWrapMap = {
  wrap: css({
    flexWrap: 'wrap'
  })
};
const baseStyles = css({
  display: 'flex',
  boxSizing: 'border-box',
  flexDirection: 'row'
});
const dividerStyles = css({
  margin: '0 -2px',
  color: "var(--ds-text-subtle, #42526E)",
  pointerEvents: 'none',
  userSelect: 'none'
});

const Divider = ({
  children
}) => jsx("span", {
  css: dividerStyles
}, children);
/**
 * __Inline__
 *
 * Inline is a primitive component based on flexbox that manages the horizontal layout of direct children.
 * Renders a `div` by default.
 *
 * @example
 * ```tsx
 * const App = () => (
 *   <Inline gap="space.100">
 *     <Button />
 *     <Button />
 *   </Inline>
 * )
 * ```
 */


const Inline = /*#__PURE__*/memo( /*#__PURE__*/forwardRef(({
  gap,
  alignItems,
  justifyContent,
  flexWrap,
  divider,
  UNSAFE_style,
  children: rawChildren,
  testId
}, ref) => {
  const dividerComponent = typeof divider === 'string' ? jsx(Divider, null, divider) : divider;
  const children = divider ? Children.toArray(rawChildren).filter(Boolean).map((child, index) => {
    return jsx(Fragment, {
      key: index
    }, divider && index > 0 ? dividerComponent : null, child);
  }) : rawChildren;
  return jsx("div", {
    style: UNSAFE_style,
    css: [baseStyles, gap && columnGapMap[gap], alignItems && flexAlignItemsMap[alignItems], justifyContent && flexJustifyContentMap[justifyContent], flexWrap && flexWrapMap[flexWrap]],
    "data-testid": testId,
    ref: ref
  }, children);
}));
Inline.displayName = 'Inline';
export default Inline;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::3bb74c0e18d35310a98408ecd49c1526>>
 * @codegenId spacing
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["columnGap"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-spacing.tsx <<SignedSource::a2b43f8447798dfdd9c6223bd22b78c7>>
 */

const columnGapMap = {
  'scale.0': css({
    columnGap: "var(--ds-space-0, 0px)"
  }),
  'scale.025': css({
    columnGap: "var(--ds-space-025, 2px)"
  }),
  'scale.050': css({
    columnGap: "var(--ds-space-050, 4px)"
  }),
  'scale.075': css({
    columnGap: "var(--ds-space-075, 6px)"
  }),
  'scale.100': css({
    columnGap: "var(--ds-space-100, 8px)"
  }),
  'scale.1000': css({
    columnGap: "var(--ds-space-1000, 80px)"
  }),
  'scale.150': css({
    columnGap: "var(--ds-space-150, 12px)"
  }),
  'scale.200': css({
    columnGap: "var(--ds-space-200, 16px)"
  }),
  'scale.250': css({
    columnGap: "var(--ds-space-250, 20px)"
  }),
  'scale.300': css({
    columnGap: "var(--ds-space-300, 24px)"
  }),
  'scale.400': css({
    columnGap: "var(--ds-space-400, 32px)"
  }),
  'scale.500': css({
    columnGap: "var(--ds-space-500, 40px)"
  }),
  'scale.600': css({
    columnGap: "var(--ds-space-600, 48px)"
  }),
  'scale.800': css({
    columnGap: "var(--ds-space-800, 64px)"
  })
};
/**
 * @codegenEnd
 */