/** @jsx jsx */
import { ReactNode } from 'react';
import type { BasePrimitiveProps } from './types';
export interface InlineProps extends BasePrimitiveProps {
    /**
     * Used to align children along the cross axis.
     */
    alignItems?: FlexAlignItems;
    /**
     * Used to align children along the main axis.
     */
    justifyContent?: FlexJustifyContent;
    /**
     * Sets whether children are forced onto one line or can wrap onto multiple lines
     */
    flexWrap?: FlexWrap;
    /**
     * Token representing gap between children.
     */
    gap: ColumnGap;
    /**
     * Renders a divider between children.
     * If a string is provided it will automatically be wrapped in a `<Text>` component.
     */
    divider?: ReactNode;
    /**
     * Elements to be rendered inside the Inline.
     */
    children: ReactNode;
}
declare type FlexAlignItems = keyof typeof flexAlignItemsMap;
declare const flexAlignItemsMap: {
    center: import("@emotion/react").SerializedStyles;
    baseline: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
};
declare type FlexJustifyContent = keyof typeof flexJustifyContentMap;
declare const flexJustifyContentMap: {
    center: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    'space-between': import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
    spaceBetween: import("@emotion/react").SerializedStyles;
};
declare type FlexWrap = keyof typeof flexWrapMap;
declare const flexWrapMap: {
    wrap: import("@emotion/react").SerializedStyles;
};
/**
 * __Inline__
 *
 * Inline is a primitive component based on flexbox that manages the horizontal layout of direct children.
 * Renders a `div` by default.
 *
 * @example
 * ```tsx
 * const App = () => (
 *   <Inline gap="space.100">
 *     <Button />
 *     <Button />
 *   </Inline>
 * )
 * ```
 */
declare const Inline: import("react").MemoExoticComponent<import("react").ForwardRefExoticComponent<InlineProps & import("react").RefAttributes<HTMLDivElement>>>;
export default Inline;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::3bb74c0e18d35310a98408ecd49c1526>>
 * @codegenId spacing
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["columnGap"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-spacing.tsx <<SignedSource::a2b43f8447798dfdd9c6223bd22b78c7>>
 */
declare const columnGapMap: {
    'scale.0': import("@emotion/react").SerializedStyles;
    'scale.025': import("@emotion/react").SerializedStyles;
    'scale.050': import("@emotion/react").SerializedStyles;
    'scale.075': import("@emotion/react").SerializedStyles;
    'scale.100': import("@emotion/react").SerializedStyles;
    'scale.1000': import("@emotion/react").SerializedStyles;
    'scale.150': import("@emotion/react").SerializedStyles;
    'scale.200': import("@emotion/react").SerializedStyles;
    'scale.250': import("@emotion/react").SerializedStyles;
    'scale.300': import("@emotion/react").SerializedStyles;
    'scale.400': import("@emotion/react").SerializedStyles;
    'scale.500': import("@emotion/react").SerializedStyles;
    'scale.600': import("@emotion/react").SerializedStyles;
    'scale.800': import("@emotion/react").SerializedStyles;
};
export declare type ColumnGap = keyof typeof columnGapMap;
/**
 * @codegenEnd
 */
