/** @jsx jsx */
import { FC, ReactNode } from 'react';
import type { BasePrimitiveProps } from './types';
declare const asAllowlist: readonly ["span", "div", "p", "strong"];
declare type AsElement = typeof asAllowlist[number];
export interface TextProps extends BasePrimitiveProps {
    /**
     * HTML tag to be rendered. Defaults to `span`.
     */
    as?: AsElement;
    /**
     * Elements rendered within the Text element
     */
    children: ReactNode;
    /**
     * Text color
     */
    color?: TextColor;
    /**
     * The HTML id attribute https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/id
     */
    id?: string;
    /**
     * Font size https://developer.mozilla.org/en-US/docs/Web/CSS/font-size
     */
    fontSize?: FontSize;
    /**
     * Font weight https://developer.mozilla.org/en-US/docs/Web/CSS/font-weight
     */
    fontWeight?: FontWeight;
    /**
     * Line height https://developer.mozilla.org/en-US/docs/Web/CSS/line-height
     */
    lineHeight?: LineHeight;
    /**
     * Truncates text with an ellipsis when text overflows its parent container
     * (i.e. `width` has been set on parent that is shorter than text length).
     */
    shouldTruncate?: boolean;
    /**
     * Text align https://developer.mozilla.org/en-US/docs/Web/CSS/text-align
     */
    textAlign?: TextAlign;
    /**
     * Text transform https://developer.mozilla.org/en-US/docs/Web/CSS/text-transform
     */
    textTransform?: TextTransform;
    /**
     * Vertical align https://developer.mozilla.org/en-US/docs/Web/CSS/vertical-align
     */
    verticalAlign?: VerticalAlign;
}
declare type FontSize = keyof typeof fontSizeMap;
declare const fontSizeMap: {
    '11px': import("@emotion/react").SerializedStyles;
    '12px': import("@emotion/react").SerializedStyles;
    '14px': import("@emotion/react").SerializedStyles;
};
declare type FontWeight = keyof typeof fontWeightMap;
declare const fontWeightMap: {
    '400': import("@emotion/react").SerializedStyles;
    '500': import("@emotion/react").SerializedStyles;
    '600': import("@emotion/react").SerializedStyles;
    '700': import("@emotion/react").SerializedStyles;
};
declare type LineHeight = keyof typeof lineHeightMap;
declare const lineHeightMap: {
    '12px': import("@emotion/react").SerializedStyles;
    '16px': import("@emotion/react").SerializedStyles;
    '20px': import("@emotion/react").SerializedStyles;
    '24px': import("@emotion/react").SerializedStyles;
    '28px': import("@emotion/react").SerializedStyles;
    '32px': import("@emotion/react").SerializedStyles;
    '40px': import("@emotion/react").SerializedStyles;
};
declare type TextAlign = keyof typeof textAlignMap;
declare const textAlignMap: {
    center: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
};
declare type TextTransform = keyof typeof textTransformMap;
declare const textTransformMap: {
    none: import("@emotion/react").SerializedStyles;
    lowercase: import("@emotion/react").SerializedStyles;
    uppercase: import("@emotion/react").SerializedStyles;
};
declare type VerticalAlign = keyof typeof verticalAlignMap;
declare const verticalAlignMap: {
    top: import("@emotion/react").SerializedStyles;
    middle: import("@emotion/react").SerializedStyles;
    bottom: import("@emotion/react").SerializedStyles;
};
/**
 * __Text__
 *
 * Text is a primitive component that has the Atlassian Design System's design guidelines baked in.
 * This includes considerations for text attributes such as color, font size, font weight, and line height.
 * It renders a `span` by default.
 *
 * @internal
 */
declare const Text: FC<TextProps>;
export default Text;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::920426feace841166c6f4ffdc49ae26d>>
 * @codegenId colors
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["text"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-light.tsx <<SignedSource::07ef29d58a2b23af8b098515466d7e22>>
 */
declare const textColorMap: {
    readonly 'color.text': import("@emotion/react").SerializedStyles;
    readonly subtle: import("@emotion/react").SerializedStyles;
    readonly subtlest: import("@emotion/react").SerializedStyles;
    readonly disabled: import("@emotion/react").SerializedStyles;
    readonly inverse: import("@emotion/react").SerializedStyles;
    readonly brand: import("@emotion/react").SerializedStyles;
    readonly selected: import("@emotion/react").SerializedStyles;
    readonly danger: import("@emotion/react").SerializedStyles;
    readonly warning: import("@emotion/react").SerializedStyles;
    readonly 'warning.inverse': import("@emotion/react").SerializedStyles;
    readonly success: import("@emotion/react").SerializedStyles;
    readonly discovery: import("@emotion/react").SerializedStyles;
    readonly information: import("@emotion/react").SerializedStyles;
};
export declare type TextColor = keyof typeof textColorMap;
/**
 * @codegenEnd
 */
